@@ -40,3 +40,11 @@ class Key:
     token: str
     precision: int
     network: str
+
+
+class Bolors:
+    OK = '\033[92m'  # GREEN
+    WARNING = '\033[93m'  # YELLOW
+    FAIL = '\033[91m'  # RED
+    RESET = '\033[0m'  # RESET COLOR
+
